eliot-dev
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Eliot-dev] Changes to eliot/game/game.h


From: eliot-dev
Subject: [Eliot-dev] Changes to eliot/game/game.h
Date: Sat, 05 Nov 2005 18:22:44 -0500

Index: eliot/game/game.h
diff -u eliot/game/game.h:1.20 eliot/game/game.h:1.21
--- eliot/game/game.h:1.20      Sat Nov  5 15:48:59 2005
+++ eliot/game/game.h   Sat Nov  5 23:22:42 2005
@@ -31,6 +31,7 @@
 class PlayedRack;
 class Round;
 class Rack;
+class Turn;
 typedef struct _Dictionary * Dictionary;
 
 using namespace std;
@@ -100,7 +101,7 @@
 
     /*************************
      * Playing the game
      * the int parameter should be 0 <= int < getNRounds
      *************************/
     int back(int);
 
@@ -125,9 +126,9 @@
 
     /**
      * Methods to access already played words.
      * The int parameter should be 0 <= int < getNRounds()
      */
-    int getNRounds() const     { return m_roundHistory.size(); }
+    int getNTurns() const     { return m_history.size(); }
     string getPlayedRack(int) const;
     string getPlayedWord(int) const;
     string getPlayedCoords(int num) const;
@@ -179,14 +180,9 @@
 
     /**
      * History of the game.
-     * All the vectors are indexed by the number of turns in the game
+     * The vector is indexed by the number of turns in the game
      */
-    // History of the racks
-    vector<PlayedRack*> m_rackHistory;
-    // History of the rounds
-    vector<Round*> m_roundHistory;
-    // ID of the players that played the round for each turn
-    vector<int> m_playerHistory;
+    vector<Turn*> m_history;
 
     int m_points;
 
@@ -100,7 +101,7 @@
     /*************************
      * Playing the game
-     * the int parameter should be 0 <= int < getNRounds
+     * the int parameter should be 0 <= int < getNTurns
      *************************/
     int back(int);
@@ -125,9 +126,9 @@
     /**
      * Methods to access already played words.
-     * The int parameter should be 0 <= int < getNRounds()
+     * The int parameter should be 0 <= int < getNTurns()
      */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]